pub struct EventEnvelope {
pub event_id: EventId,
pub session_id: SessionId,
pub branch_id: BranchId,
pub run_id: Option<RunId>,
pub seq: SeqNo,
pub timestamp: u64,
pub parent_id: Option<EventId>,
pub payload: EventPayload,
pub metadata: HashMap<String, String>,
pub schema_version: u8,
}Expand description
The universal unit of state change in Lago.
Fields
event_id: EventIdsession_id: SessionIdbranch_id: BranchIdrun_id: Option<RunId>seq: SeqNotimestamp: u64parent_id: Option<EventId>payload: EventPayloadmetadata: HashMap<String, String>schema_version: u8Schema version for forward compatibility. Defaults to 1.
Implementations
Sourceimpl EventEnvelope
impl EventEnvelope
pub fn now_micros() -> u64
Sourceimpl EventEnvelope
Convert a Lago EventEnvelope to a canonical aios_protocol::EventEnvelope.
impl EventEnvelope
Convert a Lago EventEnvelope to a canonical aios_protocol::EventEnvelope.
Uses JSON round-trip for the payload to handle all current and future event variants without maintaining a manual mapping.
pub fn to_protocol(&self) -> Option<EventEnvelope>